X-Git-Url: https://git.p6c8.net/jirafeau_mojo42.git/blobdiff_plain/30a3728e3002f864820531af817364a7b40c9cf3..1203cc4e9094fa86f7978c9da56f454d4c21ca32:/index.php
diff --git a/index.php b/index.php
index e4cfa20..63906c1 100644
--- a/index.php
+++ b/index.php
@@ -2,7 +2,7 @@
/*
* Jirafeau, your web file repository
* Copyright (C) 2013
- * Jerome Jutteau
+ * Jerome Jutteau
* Jimmy Beauvois
*
* This program is free software: you can redistribute it and/or modify
@@ -35,8 +35,14 @@ if (has_error()) {
require(JIRAFEAU_ROOT . 'lib/template/header.php');
/* Check if user is allowed to upload. */
-// First check: Challenge by IP
-if (true === jirafeau_challenge_upload_ip($cfg['upload_ip'], get_ip_address($cfg))) {
+// First check: Challenge by IP NO PASSWORD
+if (true === jirafeau_challenge_upload_ip_without_password($cfg, get_ip_address($cfg))) {
+ $_SESSION['upload_auth'] = true;
+ $_POST['upload_password'] = '';
+ $_SESSION['user_upload_password'] = $_POST['upload_password'];
+}
+// Second check: Challenge by IP
+elseif (true === jirafeau_challenge_upload_ip($cfg, get_ip_address($cfg))) {
// Is an upload password required?
if (jirafeau_has_upload_password($cfg)) {
// Logout action
@@ -101,7 +107,7 @@ else {